==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/Time/ToCalendarTime.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_Time_46hs_95toCalendarTime_35	((void*)startLabel+8)
#define CT_v281	((void*)startLabel+32)
#define F0_Time_46hs_95toCalendarTime_35	((void*)startLabel+40)
#define CT_v285	((void*)startLabel+120)
#define CT_v295	((void*)startLabel+304)
#define FN_LAMBDA277	((void*)startLabel+356)
#define CT_v307	((void*)startLabel+596)
#define F0_LAMBDA277	((void*)startLabel+604)
#define ST_v283	((void*)startLabel+644)
#define PP_Time_46hs_95toCalendarTime_35	((void*)startLabel+667)
#define PC_Time_46hs_95toCalendarTime_35	((void*)startLabel+667)
#define ST_v280	((void*)startLabel+667)
#define ST_v289	((void*)startLabel+692)
#define PP_LAMBDA277	((void*)startLabel+712)
#define PC_LAMBDA277	((void*)startLabel+712)
#define ST_v299	((void*)startLabel+712)
#define PS_v284	((void*)startLabel+740)
#define PS_v282	((void*)startLabel+752)
#define PS_v292	((void*)startLabel+764)
#define PS_v291	((void*)startLabel+776)
#define PS_v288	((void*)startLabel+788)
#define PS_v294	((void*)startLabel+800)
#define PS_v293	((void*)startLabel+812)
#define PS_v279	((void*)startLabel+824)
#define PS_v304	((void*)startLabel+836)
#define PS_v305	((void*)startLabel+848)
#define PS_v306	((void*)startLabel+860)
#define PS_v301	((void*)startLabel+872)
#define PS_v302	((void*)startLabel+884)
#define PS_v303	((void*)startLabel+896)
#define PS_v298	((void*)startLabel+908)
void FR_Time_46hs_95toCalendarTime_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok1[];
extern Node FN_NHC_46Internal_46_95apply1[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node FN_Prelude_46Enum_46Time_46Month_46toEnum[];
extern Node FN_Prelude_46Integral_46Prelude_46Int_46toInteger[];
extern Node FN_Prelude_46Enum_46Time_46Day_46toEnum[];
extern Node FN_CString_46fromCString[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];
extern Node PM_Time[];
extern Node PC_NHC_46Internal_46_95mkIOok1[];
extern Node PM_Time[];
extern Node PM_Time[];
extern Node PC_NHC_46Internal_46_95apply1[];
extern Node PM_Time[];
extern Node PM_Time[];
extern Node PM_Time[];
extern Node PC_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node PM_Time[];
extern Node PM_Time[];
extern Node PM_Time[];
extern Node PC_CString_46fromCString[];
extern Node PM_Time[];
extern Node PC_Time_46CalendarTime[];
extern Node PM_Time[];
extern Node PC_Prelude_46Monad_46NHC_46Internal_46IO_46return[];
extern Node PM_Time[];
extern Node PC_Prelude_46Enum_46Time_46Month_46toEnum[];
extern Node PM_Time[];
extern Node PC_Prelude_46Integral_46Prelude_46Int_46toInteger[];
extern Node PM_Time[];
extern Node PC_Prelude_46Enum_46Time_46Day_46toEnum[];
extern Node PM_Time[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v281)
,	/* FN_Time_46hs_95toCalendarTime_35: (byte 0) */
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_Time_46hs_95toCalendarTime_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 70022
, useLabel(ST_v280)
,	/* CT_v281: (byte 0) */
  HW(0,1)
, 0
,	/* F0_Time_46hs_95toCalendarTime_35: (byte 0) */
  CAPTAG(useLabel(FN_Time_46hs_95toCalendarTime_35),1)
, useLabel(PS_v279)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v285)
,};
Node FN_Time_46hs_95toCalendarTime[] = {
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v284)
, 0
, 0
, 0
, 0
, 70022
, useLabel(ST_v283)
,	/* CT_v285: (byte 0) */
  HW(2,0)
, 0
,};
Node CF_Time_46hs_95toCalendarTime[] = {
  VAPTAG(useLabel(FN_Time_46hs_95toCalendarTime))
, useLabel(PS_v282)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok1))
, useLabel(F0_Time_46hs_95toCalendarTime_35)
, bytes2word(1,0,0,1)
, useLabel(CT_v295)
,};
Node FN_Time_46toCalendarTime[] = {
  bytes2word(NEEDSTACK_I16,PUSH_ZAP_ARG_I1,EVAL,NEEDHEAP_I32)
, bytes2word(UNPACK,1,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,HEAP_CVAL_N1)
, bytes2word(12,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,10,HEAP_P1,0)
, bytes2word(HEAP_CVAL_P1,9,HEAP_CVAL_N1,17)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,PUSH_HEAP)
, bytes2word(HEAP_CVAL_P1,10,HEAP_CVAL_N1,22)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(17,HEAP_OFF_N1,11,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, useLabel(PS_v294)
, 0
, 0
, 0
, 0
, useLabel(PS_v293)
, 0
, 0
, 0
, 0
, useLabel(PS_v292)
, 0
, 0
, 0
, 0
, useLabel(PS_v291)
, 0
, 0
, 0
, 0
, 100001
, useLabel(ST_v289)
,	/* CT_v295: (byte 0) */
  HW(4,1)
, 0
,};
Node F0_Time_46toCalendarTime[] = {
  CAPTAG(useLabel(FN_Time_46toCalendarTime),1)
, useLabel(PS_v288)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_Time_46hs_95toCalendarTime))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
, CAPTAG(useLabel(FN_LAMBDA277),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(1,0,0,1)
, useLabel(CT_v307)
,	/* FN_LAMBDA277: (byte 0) */
  bytes2word(NEEDSTACK_I16,PUSH_ZAP_ARG_I1,EVAL,NEEDHEAP_P1)
, bytes2word(47,UNPACK,12,HEAP_CVAL_P1)
, bytes2word(7,HEAP_CVAL_N1,7,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_I1,HEAP_CVAL_P1)
, bytes2word(8,HEAP_CVAL_N1,12,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_P1,6)
, bytes2word(HEAP_CVAL_P1,9,HEAP_CVAL_N1,17)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_P1)
, bytes2word(7,HEAP_CVAL_P1,10,HEAP_CVAL_N1)
, bytes2word(22,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_P1,9,HEAP_CVAL_N1,27)
, bytes2word(HEAP_CVAL_N1,32,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_P1,0,HEAP_OFF_N1)
, bytes2word(30,HEAP_I2,HEAP_P1,3)
, bytes2word(HEAP_P1,4,HEAP_P1,5)
, bytes2word(HEAP_OFF_N1,29,HEAP_OFF_N1,24)
, bytes2word(HEAP_P1,8,HEAP_OFF_N1,20)
, bytes2word(HEAP_P1,10,HEAP_P1,11)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,11,HEAP_CVAL_N1)
, bytes2word(37,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,22,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v306)
, 0
, 0
, 0
, 0
, useLabel(PS_v305)
, 0
, 0
, 0
, 0
, CONSTR(0,12,0)
, 0
, 0
, 0
, 0
, useLabel(PS_v304)
, 0
, 0
, 0
, 0
, useLabel(PS_v303)
, 0
, 0
, 0
, 0
, useLabel(PS_v302)
, 0
, 0
, 0
, 0
, useLabel(PS_v301)
, 0
, 0
, 0
, 0
, 110074
, useLabel(ST_v299)
,	/* CT_v307: (byte 0) */
  HW(5,1)
, 0
,	/* F0_LAMBDA277: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA277),1)
, useLabel(PS_v298)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_Prelude_46Enum_46Time_46Month_46toEnum))
, VAPTAG(useLabel(FN_Prelude_46Integral_46Prelude_46Int_46toInteger))
, VAPTAG(useLabel(FN_Prelude_46Enum_46Time_46Day_46toEnum))
, VAPTAG(useLabel(FN_CString_46fromCString))
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
,};
Node PP_Time_46hs_95toCalendarTime[] = {
 };
Node PC_Time_46hs_95toCalendarTime[] = {
 	/* ST_v283: (byte 0) */
  bytes2word(84,105,109,101)
, bytes2word(46,104,115,95)
, bytes2word(116,111,67,97)
, bytes2word(108,101,110,100)
, bytes2word(97,114,84,105)
,	/* PP_Time_46hs_95toCalendarTime_35: (byte 3) */
 	/* PC_Time_46hs_95toCalendarTime_35: (byte 3) */
 	/* ST_v280: (byte 3) */
  bytes2word(109,101,0,84)
, bytes2word(105,109,101,46)
, bytes2word(104,115,95,116)
, bytes2word(111,67,97,108)
, bytes2word(101,110,100,97)
, bytes2word(114,84,105,109)
, bytes2word(101,35,0,0)
,};
Node PP_Time_46toCalendarTime[] = {
 };
Node PC_Time_46toCalendarTime[] = {
 	/* ST_v289: (byte 0) */
  bytes2word(84,105,109,101)
, bytes2word(46,116,111,67)
, bytes2word(97,108,101,110)
, bytes2word(100,97,114,84)
,	/* PP_LAMBDA277: (byte 4) */
 	/* PC_LAMBDA277: (byte 4) */
 	/* ST_v299: (byte 4) */
  bytes2word(105,109,101,0)
, bytes2word(84,105,109,101)
, bytes2word(46,116,111,67)
, bytes2word(97,108,101,110)
, bytes2word(100,97,114,84)
, bytes2word(105,109,101,58)
, bytes2word(49,49,58,55)
, bytes2word(52,0,0,0)
,	/* PS_v284: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46hs_95toCalendarTime)
, useLabel(PC_NHC_46Internal_46_95mkIOok1)
,	/* PS_v282: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46hs_95toCalendarTime)
, useLabel(PC_Time_46hs_95toCalendarTime)
,	/* PS_v292: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toCalendarTime)
, useLabel(PC_NHC_46Internal_46_95apply1)
,	/* PS_v291: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toCalendarTime)
, useLabel(PC_Time_46hs_95toCalendarTime)
,	/* PS_v288: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toCalendarTime)
, useLabel(PC_Time_46toCalendarTime)
,	/* PS_v294: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toCalendarTime)
, useLabel(PC_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61)
,	/* PS_v293: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toCalendarTime)
, useLabel(PC_LAMBDA277)
,	/* PS_v279: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46hs_95toCalendarTime_35)
, useLabel(PC_Time_46hs_95toCalendarTime_35)
,	/* PS_v304: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA277)
, useLabel(PC_CString_46fromCString)
,	/* PS_v305: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA277)
, useLabel(PC_Time_46CalendarTime)
,	/* PS_v306: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA277)
, useLabel(PC_Prelude_46Monad_46NHC_46Internal_46IO_46return)
,	/* PS_v301: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA277)
, useLabel(PC_Prelude_46Enum_46Time_46Month_46toEnum)
,	/* PS_v302: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA277)
, useLabel(PC_Prelude_46Integral_46Prelude_46Int_46toInteger)
,	/* PS_v303: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA277)
, useLabel(PC_Prelude_46Enum_46Time_46Day_46toEnum)
,	/* PS_v298: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA277)
, useLabel(PC_LAMBDA277)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_toCalendarTime" Time.hs_toCalendarTime# 1 :: Prelude.Int -> Prelude.12 */
extern NodePtr hs_toCalendarTime(HsInt);
#ifdef PROFILE
static SInfo pf_hs_toCalendarTime = {"Time","Time.hs_toCalendarTime#","Prelude.12"};
#endif
C_HEADER(FR_Time_46hs_95toCalendarTime_35) {
  NodePtr nodeptr;
  NodePtr result;
  HsInt arg1;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (HsInt)GET_INT_VALUE(nodeptr);

  result = hs_toCalendarTime(arg1);

  nodeptr = result;
  INIT_PROFINFO(nodeptr,&pf_hs_toCalendarTime);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/Time/ToCalendarTime.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_Time_46hs_95toCalendarTime_35	((void*)startLabel+8)
#define CT_v285	((void*)startLabel+32)
#define F0_Time_46hs_95toCalendarTime_35	((void*)startLabel+40)
#define CT_v289	((void*)startLabel+120)
#define CT_v299	((void*)startLabel+304)
#define FN_LAMBDA281	((void*)startLabel+356)
#define CT_v311	((void*)startLabel+596)
#define F0_LAMBDA281	((void*)startLabel+604)
#define ST_v287	((void*)startLabel+644)
#define PP_Time_46hs_95toCalendarTime_35	((void*)startLabel+667)
#define PC_Time_46hs_95toCalendarTime_35	((void*)startLabel+667)
#define ST_v284	((void*)startLabel+667)
#define ST_v293	((void*)startLabel+692)
#define PP_LAMBDA281	((void*)startLabel+712)
#define PC_LAMBDA281	((void*)startLabel+712)
#define ST_v303	((void*)startLabel+712)
#define PS_v288	((void*)startLabel+744)
#define PS_v286	((void*)startLabel+756)
#define PS_v296	((void*)startLabel+768)
#define PS_v295	((void*)startLabel+780)
#define PS_v292	((void*)startLabel+792)
#define PS_v298	((void*)startLabel+804)
#define PS_v297	((void*)startLabel+816)
#define PS_v283	((void*)startLabel+828)
#define PS_v308	((void*)startLabel+840)
#define PS_v309	((void*)startLabel+852)
#define PS_v310	((void*)startLabel+864)
#define PS_v305	((void*)startLabel+876)
#define PS_v306	((void*)startLabel+888)
#define PS_v307	((void*)startLabel+900)
#define PS_v302	((void*)startLabel+912)
void FR_Time_46hs_95toCalendarTime_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok1[];
extern Node FN_NHC_46Internal_46_95apply1[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node FN_Prelude_46Enum_46Time_46Month_46toEnum[];
extern Node FN_Prelude_46Integral_46Prelude_46Int_46toInteger[];
extern Node FN_Prelude_46Enum_46Time_46Day_46toEnum[];
extern Node FN_CString_46fromCString[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];
extern Node PM_Time[];
extern Node PC_NHC_46Internal_46_95mkIOok1[];
extern Node PC_NHC_46Internal_46_95apply1[];
extern Node PC_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node PC_CString_46fromCString[];
extern Node PC_Time_46CalendarTime[];
extern Node PC_Prelude_46Monad_46NHC_46Internal_46IO_46return[];
extern Node PC_Prelude_46Enum_46Time_46Month_46toEnum[];
extern Node PC_Prelude_46Integral_46Prelude_46Int_46toInteger[];
extern Node PC_Prelude_46Enum_46Time_46Day_46toEnum[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v285)
,	/* FN_Time_46hs_95toCalendarTime_35: (byte 0) */
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_Time_46hs_95toCalendarTime_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 70001
, useLabel(ST_v284)
,	/* CT_v285: (byte 0) */
  HW(0,1)
, 0
,	/* F0_Time_46hs_95toCalendarTime_35: (byte 0) */
  CAPTAG(useLabel(FN_Time_46hs_95toCalendarTime_35),1)
, useLabel(PS_v283)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v289)
,};
Node FN_Time_46hs_95toCalendarTime[] = {
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v288)
, 0
, 0
, 0
, 0
, 70001
, useLabel(ST_v287)
,	/* CT_v289: (byte 0) */
  HW(2,0)
, 0
,};
Node CF_Time_46hs_95toCalendarTime[] = {
  VAPTAG(useLabel(FN_Time_46hs_95toCalendarTime))
, useLabel(PS_v286)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok1))
, useLabel(F0_Time_46hs_95toCalendarTime_35)
, bytes2word(1,0,0,1)
, useLabel(CT_v299)
,};
Node FN_Time_46toCalendarTime[] = {
  bytes2word(NEEDSTACK_I16,PUSH_ZAP_ARG_I1,EVAL,NEEDHEAP_I32)
, bytes2word(UNPACK,1,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,HEAP_CVAL_N1)
, bytes2word(12,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,10,HEAP_P1,0)
, bytes2word(HEAP_CVAL_P1,9,HEAP_CVAL_N1,17)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,PUSH_HEAP)
, bytes2word(HEAP_CVAL_P1,10,HEAP_CVAL_N1,22)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(17,HEAP_OFF_N1,11,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, useLabel(PS_v298)
, 0
, 0
, 0
, 0
, useLabel(PS_v297)
, 0
, 0
, 0
, 0
, useLabel(PS_v296)
, 0
, 0
, 0
, 0
, useLabel(PS_v295)
, 0
, 0
, 0
, 0
, 100001
, useLabel(ST_v293)
,	/* CT_v299: (byte 0) */
  HW(4,1)
, 0
,};
Node F0_Time_46toCalendarTime[] = {
  CAPTAG(useLabel(FN_Time_46toCalendarTime),1)
, useLabel(PS_v292)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_Time_46hs_95toCalendarTime))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
, CAPTAG(useLabel(FN_LAMBDA281),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(1,0,0,1)
, useLabel(CT_v311)
,	/* FN_LAMBDA281: (byte 0) */
  bytes2word(NEEDSTACK_I16,PUSH_ZAP_ARG_I1,EVAL,NEEDHEAP_P1)
, bytes2word(47,UNPACK,12,HEAP_CVAL_P1)
, bytes2word(7,HEAP_CVAL_N1,7,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_I1,HEAP_CVAL_P1)
, bytes2word(8,HEAP_CVAL_N1,12,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_P1,6)
, bytes2word(HEAP_CVAL_P1,9,HEAP_CVAL_N1,17)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_P1)
, bytes2word(7,HEAP_CVAL_P1,10,HEAP_CVAL_N1)
, bytes2word(22,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_P1,9,HEAP_CVAL_N1,27)
, bytes2word(HEAP_CVAL_N1,32,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_P1,0,HEAP_OFF_N1)
, bytes2word(30,HEAP_I2,HEAP_P1,3)
, bytes2word(HEAP_P1,4,HEAP_P1,5)
, bytes2word(HEAP_OFF_N1,29,HEAP_OFF_N1,24)
, bytes2word(HEAP_P1,8,HEAP_OFF_N1,20)
, bytes2word(HEAP_P1,10,HEAP_P1,11)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,11,HEAP_CVAL_N1)
, bytes2word(37,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,22,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v310)
, 0
, 0
, 0
, 0
, useLabel(PS_v309)
, 0
, 0
, 0
, 0
, CONSTR(0,12,0)
, 0
, 0
, 0
, 0
, useLabel(PS_v308)
, 0
, 0
, 0
, 0
, useLabel(PS_v307)
, 0
, 0
, 0
, 0
, useLabel(PS_v306)
, 0
, 0
, 0
, 0
, useLabel(PS_v305)
, 0
, 0
, 0
, 0
, 110074
, useLabel(ST_v303)
,	/* CT_v311: (byte 0) */
  HW(5,1)
, 0
,	/* F0_LAMBDA281: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA281),1)
, useLabel(PS_v302)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_Prelude_46Enum_46Time_46Month_46toEnum))
, VAPTAG(useLabel(FN_Prelude_46Integral_46Prelude_46Int_46toInteger))
, VAPTAG(useLabel(FN_Prelude_46Enum_46Time_46Day_46toEnum))
, VAPTAG(useLabel(FN_CString_46fromCString))
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
,};
Node PP_Time_46hs_95toCalendarTime[] = {
 };
Node PC_Time_46hs_95toCalendarTime[] = {
 	/* ST_v287: (byte 0) */
  bytes2word(84,105,109,101)
, bytes2word(46,104,115,95)
, bytes2word(116,111,67,97)
, bytes2word(108,101,110,100)
, bytes2word(97,114,84,105)
,	/* PP_Time_46hs_95toCalendarTime_35: (byte 3) */
 	/* PC_Time_46hs_95toCalendarTime_35: (byte 3) */
 	/* ST_v284: (byte 3) */
  bytes2word(109,101,0,84)
, bytes2word(105,109,101,46)
, bytes2word(104,115,95,116)
, bytes2word(111,67,97,108)
, bytes2word(101,110,100,97)
, bytes2word(114,84,105,109)
, bytes2word(101,35,0,0)
,};
Node PP_Time_46toCalendarTime[] = {
 };
Node PC_Time_46toCalendarTime[] = {
 	/* ST_v293: (byte 0) */
  bytes2word(84,105,109,101)
, bytes2word(46,116,111,67)
, bytes2word(97,108,101,110)
, bytes2word(100,97,114,84)
,	/* PP_LAMBDA281: (byte 4) */
 	/* PC_LAMBDA281: (byte 4) */
 	/* ST_v303: (byte 4) */
  bytes2word(105,109,101,0)
, bytes2word(84,105,109,101)
, bytes2word(46,116,111,67)
, bytes2word(97,108,101,110)
, bytes2word(100,97,114,84)
, bytes2word(105,109,101,58)
, bytes2word(49,49,58,55)
, bytes2word(52,45,49,49)
, bytes2word(58,57,51,0)
,	/* PS_v288: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46hs_95toCalendarTime)
, useLabel(PC_NHC_46Internal_46_95mkIOok1)
,	/* PS_v286: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46hs_95toCalendarTime)
, useLabel(PC_Time_46hs_95toCalendarTime)
,	/* PS_v296: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toCalendarTime)
, useLabel(PC_NHC_46Internal_46_95apply1)
,	/* PS_v295: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toCalendarTime)
, useLabel(PC_Time_46hs_95toCalendarTime)
,	/* PS_v292: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toCalendarTime)
, useLabel(PC_Time_46toCalendarTime)
,	/* PS_v298: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toCalendarTime)
, useLabel(PC_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61)
,	/* PS_v297: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toCalendarTime)
, useLabel(PC_LAMBDA281)
,	/* PS_v283: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46hs_95toCalendarTime_35)
, useLabel(PC_Time_46hs_95toCalendarTime_35)
,	/* PS_v308: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA281)
, useLabel(PC_CString_46fromCString)
,	/* PS_v309: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA281)
, useLabel(PC_Time_46CalendarTime)
,	/* PS_v310: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA281)
, useLabel(PC_Prelude_46Monad_46NHC_46Internal_46IO_46return)
,	/* PS_v305: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA281)
, useLabel(PC_Prelude_46Enum_46Time_46Month_46toEnum)
,	/* PS_v306: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA281)
, useLabel(PC_Prelude_46Integral_46Prelude_46Int_46toInteger)
,	/* PS_v307: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA281)
, useLabel(PC_Prelude_46Enum_46Time_46Day_46toEnum)
,	/* PS_v302: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA281)
, useLabel(PC_LAMBDA281)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_toCalendarTime" Time.hs_toCalendarTime# 1 :: Prelude.Int -> Prelude.12 */
extern NodePtr hs_toCalendarTime(HsInt);
#ifdef PROFILE
static SInfo pf_Time_46hs_95toCalendarTime_35 = {"Time","Time.hs_toCalendarTime#","Prelude.12"};
#endif
C_HEADER(FR_Time_46hs_95toCalendarTime_35) {
  NodePtr nodeptr;
  NodePtr result;
  HsInt arg1;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (HsInt)GET_INT_VALUE(nodeptr);

  result = hs_toCalendarTime(arg1);

  nodeptr = result;
  INIT_PROFINFO(nodeptr,&pf_Time_46hs_95toCalendarTime_35);
  C_RETURN(nodeptr);
}
